function [DF_b] = DF_mg_chebyshev_b(a,par)

%  Chebyshev integrator for the polynomialization vector field of Mackey-Glass
%
%  inputs: (1) a = (a_0,a_1,a_2,...,a_N) : the Chebyshev coefficients of the solution y(t) in R^4
%		   (2) b = (b_0,b_1,b_2,...,b_N) : the Chebyshev coefficients of the history x(t) = y(t-tau) in R^4
%          (3) par = (gamma,beta,rho,tau) : the parameters

d = 4; % The vector field is in R^d with d = 4
N = length(a)/d - 1; % N+1 is the number of Chebyshev coefficients per component

beta = par(2);
rho = par(3);
tau = par(4);

i1 = (1:N+1); i2 = i1 + N+1; i3 = i2 + N+1; i4 = i3 + N+1;

a2 = a(i2); a3 = a(i3); a4 = a(i4);

DF_b = zeros(d*(N+1));

%%%% We define some convolutions to built Dphi

a2a4 = quadratic_cheb([a2;zeros(N,1)],[a4;zeros(N,1)]);
a3a4 = quadratic_cheb([a3;zeros(N,1)],[a4;zeros(N,1)]);
a4a4 = quadratic_cheb([a4;zeros(N,1)],[a4;zeros(N,1)]);

a2a2a3 = cubic_cheb([a2;zeros(N,1)],[a2;zeros(N,1)],[a3;zeros(N,1)]);

phi1_b2 = beta*eye(N+1);

phi2_b2 = zeros(N+1); phi3_b2 = zeros(N+1); phi4_b2 = zeros(N+1);

for ell=0:N
    
    k = (0:N);
    k1 = abs(k-ell)+1;
    k2 = k+ell+1;
    
    w = (1-isequal(ell,0)/2);
    
    phi2_b2(:,ell+1) = w*( beta*(a2a4(k1)+a2a4(k2)) - rho*beta*(a2a2a3(k1)+a2a2a3(k2)) );
    phi3_b2(:,ell+1) = w*( beta*(rho-2)*(a3a4(k1)+a3a4(k2)) );
    phi4_b2(:,ell+1) = w*( -beta*(a4a4(k1)+a4a4(k2)) );
    
end

T = diag(ones(1,N),-1) - diag(ones(1,N),1) ; T(1,2)=0;
Lambda_inv = diag([1 1:N].^(-1));

%%% F1_b2 %%%
DF_b(i1,i2) = - (tau/4)*Lambda_inv*T*phi1_b2;

%%% F2_b2 %%%
DF_b(i2,i2) = - (tau/4)*Lambda_inv*T*phi2_b2;

%%% F3_b2 %%%
DF_b(i3,i2) = - (tau/4)*Lambda_inv*T*phi3_b2;

%%% F4_b2 %%%
DF_b(i4,i2) = - (tau/4)*Lambda_inv*T*phi4_b2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% d_Fj_0/d_aj (j=1,2,3,4) %
%%%%%%%%%%%%%%%%%%%%%%%%%%%

at_plus1 = [1 2*ones(1,N)]';

DF_b(i1(1),i1) = -at_plus1;
DF_b(i2(1),i2) = -at_plus1;
DF_b(i3(1),i3) = -at_plus1;
DF_b(i4(1),i4) = -at_plus1;

end
