function DF_spectrum = DF_spectrum_PO_mg_chebyshev(x,par,m)

%  Matrix (from Jay and Jorge's paper) for the computation of m-periodic orbits in the MG equation
%
%  inputs: (1) x = [alpha,a] (the variables), where
%                a = (a^1,a^2,...,a^m) : the Chebyshev coeffs of the iterates
%          (2) m : the number of iterates it takes to get a periodic orbit

tau = x(1);
eta = x(2:4);
a = x(5:end);
par(4) = tau;
par(5:7)=eta;
d = 4;

N = length(a)/(m*d) - 1; % N+1 is the number of Chebyshev coefficients per iterate

DF_PO = DF_PO_mg_up_chebyshev(x,par,m);
DF_PO(1:4,:)=[]; DF_PO(:,1:4)=[];

DF_spectrum = zeros(m*d*(N+1));

ind_1 = 1:d*(N+1);
ind_m = (m-1)*d*(N+1)+1:m*d*(N+1);

E = zeros(d*(N+1),m);

M1 = DF_PO(ind_m,ind_1); M2 = -DF_PO(ind_m,ind_m);
DF_spectrum(ind_1,ind_m) = M1\M2;
[~,D] = eig(M1\M2); E(:,1) = diag(D);

for j=2:m
    ind_jm1 = (j-2)*d*(N+1)+1:(j-1)*d*(N+1); ind_j = (j-1)*d*(N+1)+1:j*d*(N+1);
    M1 = DF_PO(ind_jm1,ind_j);
    M2 = -DF_PO(ind_jm1,ind_jm1);
    DF_spectrum(ind_j,ind_jm1) = M1\M2;
    [~,D] = eig(M1\M2); E(:,j) = diag(D);
end

% R = zeros(m,N+1);
% 
% for i = 1:N+1
%     pol = [1 zeros(1,m-1) -prod(E(i,:))];
%     R(:,i)=roots(pol);
% end
% 
% Eigs = reshape(R,m*(N+1),1);
% figure
% plot(real(Eigs),imag(Eigs),'*','color',[0 0 0])

end