function DF_PO = int_DF_PO_mg_up_chebyshev(x,par,m)

%  Jacobian for the computation of m-periodic orbits in Mackey-Glass
%
%  inputs: (1) x = [tau,a] (the variables), where
%                a = (a^1,a^2,...,a^m) : the Chebyshev coeffs of the iterates
%          (2) par = [gamma,beta,rho]
%          (3) m : the number of iterates it takes to get a periodic orbit

tau = x(1);
eta = x(2:4);
a = x(5:end);
par(4) = tau;
par(5:7)=eta;
d = 4;

N = length(a)/(m*d) - 1; % N+1 is the number of Chebyshev coefficients per iterate
a = reshape(a,d*(N+1),m);

DF_PO = intval(zeros(m*d*(N+1)+4));

%%% derivative of the phase conditions %%%

at_minus1 = intval([1 2*(-1).^(1:N)]);

i1 = 1:N+1; i2 = i1 + N+1; i3 = i2 + N+1; i4 = i3 + N+1;

DF_PO(1,i1+4) = at_minus1;
DF_PO(2,i2+4) = at_minus1;
DF_PO(3,i3+4) = at_minus1;
DF_PO(4,i4+4) = at_minus1;

%%% Derivative of the map w.r.t. tau and the unfolding parameters %%%

f_PO_tau = intval(zeros(d*(N+1),m)); 
f_PO_eta1 = intval(zeros(d*(N+1),m));
f_PO_eta2 = intval(zeros(d*(N+1),m));
f_PO_eta3 = intval(zeros(d*(N+1),m));

T = intval(diag(ones(1,N),-1) - diag(ones(1,N),1)) ; T(1,2)=0;
Lambda_inv = intval(diag([1 1:N].^(-1)));

v1 = - (tau/4)*Lambda_inv*T*[1;zeros(N,1)];

for j=1:m-1
    
    aj = a(:,j);
    ajp1 = a(:,j+1);
    f_PO_tau(:,j) = int_F_mg_up_chebyshev_tau(ajp1,aj,par);
    f_PO_eta1(i2,j) = v1;
    f_PO_eta2(i3,j) = v1;
    f_PO_eta3(i4,j) = v1;
    
end

a1 = a(:,1); am = a(:,m);
f_PO_tau(:,m) = int_F_mg_up_chebyshev_tau(a1,am,par);

f_PO_eta1(i2,m) = v1;
f_PO_eta2(i3,m) = v1;
f_PO_eta3(i4,m) = v1;

f_PO_tau = reshape(f_PO_tau,d*m*(N+1),1);
f_PO_eta1 = reshape(f_PO_eta1,d*m*(N+1),1);
f_PO_eta2 = reshape(f_PO_eta2,d*m*(N+1),1);
f_PO_eta3 = reshape(f_PO_eta3,d*m*(N+1),1);

DF_PO(5:end,2) = f_PO_eta1;
DF_PO(5:end,3) = f_PO_eta2;
DF_PO(5:end,4) = f_PO_eta3;

DF_PO(5:end,1) = f_PO_tau;

%%% Derivative of the rest of the map f w.r.t. a %%%

Df_a = intval(zeros(m*d*(N+1)));

for j=1:m-1
    ind_j = (j-1)*d*(N+1)+1:j*d*(N+1); ind_jp1 = j*d*(N+1)+1:(j+1)*d*(N+1);
    aj = a(:,j);
    ajp1 = a(:,j+1);
    Df_a(ind_j,ind_j) = int_DF_mg_chebyshev_b(ajp1,par);
    Df_a(ind_j,ind_jp1) = int_DF_mg_chebyshev(ajp1,aj,par);
end

a1 = a(:,1); am = a(:,m);
ind_1 = 1:d*(N+1); ind_m = (m-1)*d*(N+1)+1:m*d*(N+1);

Df_a(ind_m,ind_1) = int_DF_mg_chebyshev(a1,am,par);
Df_a(ind_m,ind_m) = int_DF_mg_chebyshev_b(a1,par);

DF_PO(5:end,5:end) = Df_a;

end