function F_PO_ext = int_F_PO_mg_up_chebyshev_ext(x,par,m)

%  Computation of m-periodic orbits in Mackey-Glass
%
%  inputs: (1) x = [tau,eta,a] (the variables), where
%               tau is the delay, eta \in R^3 are the unfolding parameters
%               and a = (a^1,a^2,...,a^m) are the Chebyshev coeffs of the iterates
%          (2) m : the number of iterates it takes to get a periodic orbit

tau = x(1);
eta = x(2:4);
a = x(5:end);
y1_0 = intval(par(4));
par(4) = tau;
par(5:7)=eta;
d = 4;

N = length(a)/(m*d) - 1; % N+1 is the number of Chebyshev coefficients per iterate
a = intval(reshape(a,d*(N+1),m));

F_PO_ext = intval(zeros(d*(4*N+1),m));

for j=1:m-1
    
    aj = a(:,j);
    ajp1 = a(:,j+1);
    F_PO_ext(:,j) = int_F_mg_up_chebyshev_ext(ajp1,aj,par);
    
end

a1 = a(:,1); am = a(:,m);
F_PO_ext(:,m) = int_F_mg_up_chebyshev_ext(a1,am,par);

F_PO_ext = reshape(F_PO_ext,d*m*(4*N+1),1);

% Phase conditions (We look for a periodic orbit oscillating about 1)

phase = intval(zeros(4,1));

at_minus1 = intval([1 2*(-1).^(1:N)]');

rho = par(3);
y2_0 = y1_0/(1+y1_0^rho);
y3_0 = y1_0^(rho-2);
y4_0 = 1/y1_0;

phase(1) = sum(at_minus1.*a1(1:N+1)) - y1_0;
phase(2) = sum(at_minus1.*a1(N+2:2*N+2)) - y2_0;
phase(3) = sum(at_minus1.*a1(2*N+3:3*N+3)) - y3_0;
phase(4) = sum(at_minus1.*a1(3*N+4:4*N+4)) - y4_0;

F_PO_ext = [phase;F_PO_ext];

end