function [F] = int_F_mg_up_chebyshev_tau(a,b,par)

%  Chebyshev integrator for the polynomialization vector field of Mackey-Glass
%
%  inputs: (1) a = (a_0,a_1,a_2,...,a_N) : the Chebyshev coefficients of the solution y(t) in R^4
%		   (2) b = (b_0,b_1,b_2,...,b_N) : the Chebyshev coefficients of the history x(t) = y(t-tau) in R^4
%          (3) par = (gamma,beta,rho,tau,eta) : the parameters and the unfolding ones (eta in R^3)

d = 4; % The vector field is in R^d with d = 4
N = length(a)/d - 1; % N+1 is the number of Chebyshev coefficients per component

gamma = par(1);
beta = par(2);
rho = par(3);
eta = par(5:7);

a1 = a(1:N+1); a2 = a(N+2:2*N+2); a3 = a(2*N+3:3*N+3); a4 = a(3*N+4:4*N+4);
b2 = b(N+2:2*N+2); 

a1a2a4 = rig_convolution([a1 a2 a4]);
a1a3a4 = rig_convolution([a1 a3 a4]);
a1a4a4 = rig_convolution([a1 a4 a4]);
a2a4b2 = rig_convolution([a2 a4 b2]);
a3a4b2 = rig_convolution([a3 a4 b2]);
a4a4b2 = rig_convolution([a4 a4 b2]);
a1a2a2a3 = rig_convolution([a1 a2 a2 a3]);
a2a2a3b2 = rig_convolution([a2 a2 a3 b2]);

phi1 = -gamma*a1 + beta*b2;
phi2 = -gamma*a1a2a4(1:N+1) + beta*a2a4b2(1:N+1) + rho*gamma*a1a2a2a3(1:N+1) - rho*beta*a2a2a3b2(1:N+1) + [eta(1);zeros(N,1)];
phi3 = -gamma*(rho-2)*a1a3a4(1:N+1) + beta*(rho-2)*a3a4b2(1:N+1) + [eta(2);zeros(N,1)];
phi4 = gamma*a1a4a4(1:N+1) - beta*a4a4b2(1:N+1) + [eta(3);zeros(N,1)];

T = intval(diag(ones(1,N),-1) - diag(ones(1,N),1)) ; T(1,2)=0;
Lambda_inv = intval(diag([1 1:N].^(-1)));

F1 = - (1/intval(4))*Lambda_inv*T*phi1;
F1(1) = 0;

F2 = - (1/intval(4))*Lambda_inv*T*phi2;
F2(1) = 0;

F3 = - (1/intval(4))*Lambda_inv*T*phi3;
F3(1) = 0;

F4 = - (1/intval(4))*Lambda_inv*T*phi4;
F4(1) =  0;

F = [F1;F2;F3;F4];

end