function [DF] = DF_wright_chebyshev(a,b,alpha)

%  inputs: (1) a = (a0,a1,...,aN) : the Chebyshev coefficients of the solution y(t)
%		   (2) b = (b0,b1,...,bN) : the Chebyshev coefficients of the history x(t) = y(t-1)
%          (3) alpha : the parameter

N = length(a)/1 - 1; % N+1 is the number of Chebyshev coefficients per component
tau = 1;

b_ext = [b;zeros(N,1)];

phi_a = zeros(N+1);

for ell=0:N
    
    k = (0:N);
    k1 = abs(k-ell)+1;
    k2 = k+ell+1;
    
    w = (1-isequal(ell,0)/2);
    
    phi_a(:,ell+1) = w*( -alpha*(b_ext(k1)+b_ext(k2)) );
    
end

T = diag(ones(1,N),-1) - diag(ones(1,N),1) ; T(1,2)=0;
Lambda_inv = diag([1 1:N].^(-1));
Id = eye(N+1);

%%% F_a %%%
DF = Id - (tau/4)*Lambda_inv*T*phi_a;

%%%%%%%%%%%%%
% d_F_0/d_a %
%%%%%%%%%%%%%

at_minus1 = [1 2*(-1).^(1:N)]';

DF(1,:) = at_minus1;

end
