function F = int_F_wright_chebyshev_ext(a,b,alpha)

%  inputs: (1) a = (a0,a1,...,aN) : the Chebyshev coefficients of the solution y(t)
%		   (2) b = (b0,b1,...,bN) : the Chebyshev coefficients of the history x(t) = y(t-1)
%          (3) alpha : the parameter

N = length(a) - 1; % N+1 is the number of Chebyshev coefficients per component
tau = 1;

ab = rig_convolution([a b]);

phi = -alpha*[b;zeros(N,1)] - alpha*ab;

at_minus1 = [1 2*(-1).^(1:N)]';
at_plus1 = [1 2*ones(1,N)]';

T = diag(ones(1,2*N),-1) - diag(ones(1,2*N),1) ; T(1,2)=0;
Lambda_inv = diag([1 1:2*N].^(-1));

F = [a;zeros(N,1)] - (tau/4)*Lambda_inv*T*phi;
F(1) = sum(at_minus1.*a) - sum(at_plus1.*b);

end