function [I,success] = int_rad_poly_step_wright(a,b,alpha,delta0,nu,C1)

plot_spectrum = 0;

N = length(a) - 1;

iDF = int_DF_wright_chebyshev(a,b,alpha);
A = mid(iDF)\eye(N+1); iA = intval(A);

tau = 1;
i4 = intval(4); iN = intval(N);

nu = intval(nu);

%%%%%%%%%%
%%% Y0 %%%
%%%%%%%%%%

f0 = int_F_wright_chebyshev_ext(a,b,alpha);
y0 = [iA*f0(1:N+1);(1./(N+1:2*N)').*f0(N+2:2*N+1)];
Y0_1 = nu_norm(y0,nu);

Lambda_inv = intval(diag([1 (1:N).^(-1)]));
T = intval(diag(ones(1,N),-1) - diag(ones(1,N),1)) ; T(1,2)=0;
hat_one = intval([1;zeros(N,1)]);
vec = Lambda_inv*T*(hat_one+a);
Y0_2 = (nu_norm(iA(:,1),nu) + tau*abs(alpha)/2*nu_norm(iA(:,2:end)*vec(2:end),nu) )*delta0;
Y0 = sup(Y0_1 + Y0_2);

%%%%%%%%%%
%%% Z0 %%%
%%%%%%%%%%

B = intval(eye(N+1)) - iA*iDF;
Z0 = sup(matrix_norm(B,1,nu));

%%%%%%%%%%
%%% Z1 %%%
%%%%%%%%%%

Psi = int_compute_Psi_k(b,nu);
hat_z1 = (tau*alpha/i4)*intval([1 (1:N).^(-1)]').*abs(T)*intval(Psi);
hat_z1(1) = 1/nu^(iN+1);

z1_1 = nu_norm(abs(iA)*hat_z1,nu) + (tau*alpha/(i4*(N+1)))*(2*nu+1/nu)*nu_norm(b,nu);

norm_A_Lambda_inv = max(matrix_norm(iA*Lambda_inv,1,nu),1/(iN+1));
z1_2 = (tau*alpha/i4)*norm_A_Lambda_inv*(2*nu+1/nu)*delta0;

Z1 = sup(z1_1 + z1_2);

%%%%%%%%%%%%%%%%%%%%
% Radii polynomial %
%%%%%%%%%%%%%%%%%%%%

disp(['Y0 = ',num2str(Y0),', Z0 = ',num2str(Z0),', Z1 = ',num2str(Z1)])

iY0 = intval(Y0); iZ0 = intval(Z0); iZ1 = intval(Z1);

if sup(iZ0+iZ1)>=1
    I=[-1 -1];
    success=0;
else
    r_minus = sup(iY0/(1-iZ0-iZ1));
    I = [r_minus Inf];
    success=1;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Rigorous control over ||DF(x) - M|| %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if success == 1 && C1 == 1
    
    % delta_0
    norm_A = max(matrix_norm(iA,1,nu),1);
    delta0 = 1+tau*alpha/4*(2*nu+1/nu)*(1+nu_norm(a,nu)+r_minus);
    
    % delta_1
    Psi_a = int_compute_Psi_k(a,nu);
    hat_z = (tau*alpha/i4)*intval([1 (1:N).^(-1)]').*abs(T)*intval(Psi_a);
    hat_z(1) = 1/nu^(iN+1);
    
    delta1 = nu_norm(abs(iA)*hat_z,nu) + (tau*alpha/(i4*(N+1)))*(2*nu+1/nu)*(1+nu_norm(a,nu));
    
    delta = ((Z0+Z1)/(1-Z0-Z1))*norm_A*delta0 + delta1;
    
    disp(['||DF(x) - M|| <= ',num2str(sup(delta))])
    
    if plot_spectrum == 1
    
    DF2 = DF2_wright_chebyshev(a,b,alpha);
    M = A*DF2;
    
    [~,D] = eig(M); Eigs = diag(D);
    
    figure
    plot(real(Eigs),imag(Eigs),'*','color',[0 0 0])
    hold on
    
    set(gca,'FontSize',20)
    
    xlabel('$$Re(\lambda)$$','interpreter','latex','FontSize',25)
    ylabel('$$Im(\lambda)$$','interpreter','latex','FontSize',25)
    
    axis equal
    box off
    
    r = 1; color = [0.7 0 0]; s = (0:.002:2*pi); circle = r*exp(1i*s); plot(real(circle),imag(circle),'color',color,'linewidth',2)
    
    end
    
end

end

