function a = integrate_one_step_wright(b,alpha)

%  Chebyshev integrator for Wright's equation (uses Chebfun & dde23)
%
%  inputs: (1) b = (b0,b1,...,bN) : the Chebyshev coefficients of the history y(t-1) in R
%          (2) par = (gamma,beta,rho,tau) : the parameters 
%  output : a = (a0,a1,...,aN) : the Chebyshev coefficients of the solution y(t) in R

tau = 1;
range = [0 tau];

b(2:end) = 2*b(2:end);
h = chebfun(b,[-tau 0],'coeffs');
tspan = -tau:.001:0;

his(1,:) = tspan;
his(2,:) = h(tspan);

[t,y] = dde_integ_wright(alpha,range,his);

I = find(t>=0);
t0 = t(I); y0 = y(I);

t1 = 0:.001:tau; 
y1 = interp1(t0,y0,t1)';

%plot(t1,y1,'color',[0 0 1])

% Extracting the chebyshev coefficients from the time series
v1 = chebfun(y1,'equi');

a = chebcoeffs(v1); a(2:end) = a(2:end)/2;

end